# BOX_KEEP_UPS

"Box Keep Ups" is a simple offline game created using Kivy. In this game, the player needs to move the box to ensure
that the ball bounces and does not touch the ground.

# Executable File

The executable file is downloadable at 
https://github.com/NativeApkDev/BOX_KEEP_UPS/blob/master/BOX_KEEP_UPS/dist/BoxKeepUps/BoxKeepUps.

# Source Code

Python code used to create the game is available in the files in 
https://github.com/NativeApkDev/BOX_KEEP_UPS/tree/master/BOX_KEEP_UPS.

# Installation

Enter the command "pip install BOX_KEEP_UPS".

# How to Use the Executable File?

First, open by double-clicking the file "BoxKeepUps". 
How the executable file looks like is shown in the image below (the file is enclosed with a red rectangle).

![Executable File](images/Executable%20File.png)

# About The Game

In the game, your goal is to get the ball to bounce off the box as many times as possible without hitting the ground.
The box can be moved by clicking on the screen to the direction where you want to move the box to. The box can only 
be moved in horizontal direction. The following image shows how the game interface looks like.

![About The Game](images/About%20The%20Game.png)